@@ -5,12 +5,16 @@
 
 """
 import argparse
+import os
 from collections import deque
 
-from wpy.files import FileUtils
-from wpy.argument import Action
-from wpy.argument import CommandArgumentParserFactory
+from wpy.path import (
+    read_dict, write_yml
+)
+from csarg import Action
+from csarg import CommandArgumentParserFactory
 
+from wush.config import load_config
 from wush.argument.command import CmdArgumentParser
 
 def init_argparse():
@@ -71,6 +75,7 @@ class EnvArgumentParser(CmdArgumentParser):
             help="添加环境变量")
 
         item.sys_parser = init_argparse()
+        item.config = load_config()
 
         return item
 
@@ -89,6 +94,9 @@ class EnvArgumentParser(CmdArgumentParser):
             for key_val in sys_args.add:
                 key, val = key_val.split('=')
                 self.config.add_env(key, val)
+                # 写入当前环境变量
+                # TODO 需要禁止修改敏感字段
+                os.environ[key] = val
 
         output = {
             'headers': [
@@ -108,7 +116,7 @@ class EnvArgumentParser(CmdArgumentParser):
             env_path = self.wapi.config.get_env_path()
             env_data = {}
             try:
-                env_data = FileUtils.read_dict(env_path)
+                env_data = read_dict(env_path)
             except:
                 pass
             for k, v in self.wapi.config.env.dict().items():
@@ -122,5 +130,10 @@ class EnvArgumentParser(CmdArgumentParser):
                     continue
                 self.logger.info('Env save %s=%s', k, v)
                 env_data[k] = v
-            FileUtils.write_yml(env_path, env_data)
+            write_yml(env_path, env_data)
 
+    def run_shell(self, args):
+        self.run(args)
+
+    def run_command(self, args):
+        self.run(args)
