@@ -5,12 +5,17 @@
 """
 
 import json
+from typing import Any, Dict, Callable
+from requests.cookies import RequestsCookieJar
+from requests import Response
 
 from wpy.base import BaseEnum
 from wpy.base import BaseObject
 
-from wush.web.enums import HeaderEnum
 from wush.web.enums import ContentTypeEnum
+from .models import RequestBuilder, Header
+
+__all__ = ['ResponseClient']
 
 class ResponseField(BaseEnum):
     HEADERS = 'headers'
@@ -24,44 +29,47 @@ class ResponseField(BaseEnum):
 
 class ResponseClient(BaseObject):
     """返回客户端"""
-    request_builder = None
-    content = None
-    text = None
-    status_code = None
-    url = None
-    ok = None
-    headers = None
-    cookies = None
+    request_builder: RequestBuilder
+    content: bytes
+    text: str
+    status_code: int
+    url: str
+    ok: bool = None
+    headers: Header
+    cookies: RequestsCookieJar = None
+    response: Response
 
-    def __init__(self, request_builder, response):
+    def __init__(self, request_builder: RequestBuilder, response: Response):
         self.request_builder = request_builder
         self.response = response
         for key in ResponseField.values():
-            setattr(self, key, getattr(self.response, key))
+            value = getattr(self.response, key)
+            if key == ResponseField.HEADERS.value:
+                value = Header(**value)
+
+            setattr(self, key, value)
 
     @property
-    def content_type(self):
-        return self.headers[HeaderEnum.CONTENT_TYPE.value]
+    def content_type(self) -> str:
+        return self.headers.content_type
+
+    #  @property
+    #  def location(self) -> str:
+        #  return self.headers[HeaderEnum.LOCATION.value]
 
     @property
-    def location(self):
-        return self.headers[HeaderEnum.LOCATION.value]
-
-    @property
-    def is_html(self):
+    def is_html(self) -> bool:
         return ContentTypeEnum.TEXT_HTML.value in self.content_type
 
     @property
-    def is_json(self):
+    def is_json(self) -> bool:
         """判断结果是否为 json 格式"""
-        if ContentTypeEnum.APPLICATION_JSON.value in self.content_type:
-            return True
-        return False
+        return ContentTypeEnum.APPLICATION_JSON.value in self.content_type
 
-    def json(self, **kwargs):
+    def json(self, **kwargs) -> Any:
         return self.response.json(**kwargs)
 
-    def save(self, savepath=None):
+    def save(self, savepath: str=None):
         """保存"""
         if self.is_json:
             with open(savepath, 'w') as f:
@@ -79,10 +87,10 @@ class ResponseClient(BaseObject):
 
 class ResponseHandler(BaseObject):
 
-    _factory = {}
+    _factory: Dict[str, Callable[[ResponseClient], Any]] = {}
 
     @classmethod
-    def register(cls, module, name):
+    def register(cls, module: str, name: str) -> Callable[[Callable], Any]:
         def decorate(func):
             key = f"{module}-{name}"
             cls._factory[key] = func
@@ -90,9 +98,9 @@ class ResponseHandler(BaseObject):
         return decorate
 
     @classmethod
-    def get_handler(cls, module, name):
+    def get_handler(cls, module: str, name: str
+            ) -> Callable[[ResponseClient], Any]:
         """获取处理结果的方法
-
         """
         key = f"{module}-{name}"
         return cls._factory.get(key)
